#!/bin/sh
#
# author: Joerg Heinemann
# website: http://enterprise-log-management-appliance.org
# license: GPL v3
#
# /usr/lib/nagios/plugins/check_rsyslog.sh
# 
# check_rsyslog plugin for Nagios 3.x
#
# Tested on openSUSE 12.3-13.1 with ELMA and rsyslog-testtools packages installed.
#

# Description:
#
# This plugin will attempt to send syslog events to syslog forwarders and 
# checks if any events was received by this job. 
# It needs the rsyslog-testtools and ELMA programs installed on your server (see Notes). 
# 
# NOTES: 
#  - This plugin requires that ELMA package is installed. 
#  - ELMA is part of the openSUSE appliance (see above)
#

# Example of command definitions for Nagios 3.x:
#
# define command{
# command_name	check_rsyslog
# command_line	$USER1$/check_rsyslog.sh -t$HOSTADDRESS$ $ARG1$ $ARG2$ $ARG3$ $ARG4$ $ARG5$ $ARG6$ $ARG7$ $ARG8$
# }

# tcpflood options:
#
# -t 	target address (default 127.0.0.1)
# -p 	target port (default 13514)
# -c 	number of connections (default 1)
# -m 	number of messages to send (connection is random)
# -d 	amount of extra data to add to message. If present, the number itself will be added as third field, and the data bytes as forth. Add -r to randomize the amount of extra data included in the range 1..(value of -d).
# -r 	randomize amount of extra data added (-d must be > 0)
# -R 	number of times the test shall be run (very useful for gathering performance data and other repetitive things). Default: 1
# -S 	number of seconds to sleep between different runs (-R) Default: 30
# -T 	transport to use. Currently supported: "udp", "tcp" (default) Note: UDP supports a single target port, only
## -z 	private key file for TLS mode (not implemented into ELMA at this time)
## -Z 	cert (public key) file for TLS mode (not implemented into ELMA at this time)
## -L 	loglevel to use for GnuTLS troubleshooting (0-off to 10-all, 0 default) (not implemented into ELMA at this time)
#
# Example of option definitions: send 100 messages of 200 bytes plus header, 3 times, every second
#
# ELMA_PROBE_PARAMETER="-t127.0.0.1 -Tudp -p514 -d200 -m100 -R3 -S1 -c1"
#
# NOTE: Only 8 option parameter will be accepted!
#
ELMA_PROBE_PARAMETER="$1 $2 $3 $4 $5 $6 $7 $8 $9"

# Path
#
ELMA_PROBE="/usr/share/elma-tests/bin/elma_nagios_probe.sh"

source $ELMA_PROBE $ELMA_PROBE_PARAMETER > /dev/null

case $RETVAL in
	0)
		echo "Syslog Forwarding OK - $TEST_SUMMARY|$PERF_DATA"
		echo -e "$TEST_OUTPUT|"
		exit 0
		;;
	1)
		echo "Syslog Forwarding WARNING - $TEST_SUMMARY|$PERF_DATA"
		echo -e "$TEST_OUTPUT|"
		exit 1
		;;
	2)
		echo "Syslog Forwarding CRITICAL - $TEST_SUMMARY|$PERF_DATA"
		echo -e "$TEST_OUTPUT|"
		exit 2
		;;
	3)
		echo "Syslog Forwarding UNKNOWN - $TEST_SUMMARY|$PERF_DATA"
		echo -e "$TEST_OUTPUT|"
		exit 3
		;;
	*)
		echo "Syslog Forwarding DEPENDENT - $TEST_SUMMARY|$PERF_DATA"
		echo -e "$TEST_OUTPUT|"
		exit 4
		;;
esac